import { EventMeta, OnErrorHandler } from 'trackx/types';

/** Global meta data sent with every event. Must be JSON serialisable. */
declare const meta: EventMeta;
/**
 * Programmatically send an error event.
 *
 * @param error - The error to report.
 * @param extraMeta - Additional meta data to send with this event.
 */
declare function sendEvent(error: Error, extraMeta?: EventMeta): void;
/**
 * Set up error tracking.
 *
 * @param endpoint - The full API endpoint URL e.g., `"https://api.trackx.app/v1/uvxpkibb17b/event"`.
 *
 * @param onError - Optional function that will be called before every event is
 * sent allowing you to mutate its payload data or prevent sending the event.
 */
declare function setup(endpoint: string, onError?: OnErrorHandler): void;
/** Send ping to register a session. */
declare function ping(): void;

export { meta, ping, sendEvent, setup };
