import { EventMeta, OnErrorHandler } from 'trackx/types';

/** Global meta data sent with every event. Must be JSON serialisable. */
declare const meta: EventMeta;
/**
 * Programmatically send an error event.
 *
 * @param error - The error to report.
 * @param extraMeta - Additional meta data to send with this event.
 */
declare function sendEvent(error: Error, extraMeta?: EventMeta): void;
/**
 * Set up error tracking.
 *
 * @param endpoint - API endpoint; a URL including server origin, API version,
 * and your project ID e.g., `"https://api.trackx.app/v1/uvxpkibb17b"`.
 * @param onError - Optional function that will be called before every event is
 * sent allowing you to mutate its payload data or prevent sending the event.
 * @param origin - Optional `Origin` header to send with event network requests.
 * Use together with the allowed origins setting in the dash to restrict access
 * to your project endpoint. (Default `"null"`). Note: This option is only
 * available in the trackx/node client.
 */
declare function setup(endpoint: string, onError?: OnErrorHandler, origin?: string): void;
declare function setup(endpoint: string, origin?: string): void;
/** Send ping to register a session. */
declare function ping(): void;

export { meta, ping, sendEvent, setup };
